BernoulliNegativeSampler
========================

.. currentmodule:: pykeen.sampling

.. autoclass:: BernoulliNegativeSampler
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~BernoulliNegativeSampler.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~BernoulliNegativeSampler.sample

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: sample
